#!/usr/bin/env python

# Requires h5py library
# Usage:
#  compare_unifrac_pcoa.py fname_single fname_multi nmulti elements precision
#
# Example:
#  compare_unifrac_pcoa.py test500.unweighted_fp32.f.h5 a.h5 3 0.1
#
import h5py
import sys

fname1=sys.argv[1]
fname2=sys.argv[2]
mcount=int(sys.argv[3])
els=int(sys.argv[4])
prec=float(sys.argv[5])

d1= h5py.File(fname1)['pcoa_eigvals'][:els]
for i in range(mcount):
  d2= h5py.File(fname2)['pcoa_eigvals:%i'%i][:els]

  l1=len(d1)
  l2=len(d2)
  if (l1!=l2):
    print("Multi %i has the wrong number of eigvals"%i)
    sys.exit(1)

  m=max(abs((d1[:]-d2[:])/d1[:]))
  if (m>prec):
    print("Diff too large for multi %i: %e>%e "%(i,m,prec))
    print("Raw data:",d1,d2, abs((d1[:]-d2[:])/d1[:]))
    sys.exit(2)

print("Files match within precision")



#!/usr/bin/env python

# Requires h5py library
# Usage:
#  compare_unifrac_pcoa.py fname1 fname2 elements precision
#
# Example:
#  compare_unifrac_pcoa.py test500.unweighted_fp32.f.h5 a.h5 3 0.1
#
import h5py
import sys

fname1=sys.argv[1]
fname2=sys.argv[2]
els=int(sys.argv[3])
prec=float(sys.argv[4])

d1= h5py.File(fname1)['pcoa_eigvals'][:els]
d2= h5py.File(fname2)['pcoa_eigvals'][:els]

l1=len(d1)
l2=len(d2)
if (l1!=l2):
  print("The two files do not have the same number of elements")
  sys.exit(1)

m=max(abs((d1[:]-d2[:])/d1[:]))
if (m>prec):
    print("Diff too large: %e>%e "%(m,prec))
    print("Raw data:",d1,d2, abs((d1[:]-d2[:])/d1[:]))
    sys.exit(2)

print("Files match within precision")



#!/usr/bin/env python

# Requires h5py library
# Usage:
#  compare_unifrac_matrix.py fname1 fname2 precisio
#
# Example:
#  compare_unifrac_matrix.py test500.unweighted_fp32.f.h5 a.h5 1.e-5
#
import h5py
import sys

fname1=sys.argv[1]
fname2=sys.argv[2]
prec=float(sys.argv[3])

d1= h5py.File(fname1)['matrix'][:,:]
d2= h5py.File(fname2)['matrix'][:,:]

l1=len(d1)
l2=len(d2)
if (l1!=l2):
  print("The two files do not have the same number of rows")
  sys.exit(1)

for r in range(l1):
  m=max(abs(d1[r,:]-d2[r,:]))
  if (m>prec):
    print("Diff too large at row %i: %e>%e"%(r,m,prec))
    sys.exit(2)
print("Files match within precision")



#!/usr/bin/env python

# Requires h5py library
# Usage:
#  compare_unifrac_stats.py fname n_groups n_perms value pvalue prec_value prec_pvalue
#
# Example:
#  compare_unifrac_stats.py a.h5 5 999 1.001112 0.456  0.001 0.1
#
import h5py
import sys

fname1=sys.argv[1]
n_groups=int(sys.argv[2])
n_perms=int(sys.argv[3])
value=float(sys.argv[4])
pvalue=float(sys.argv[5])
precv=float(sys.argv[6])
precp=float(sys.argv[7])

d= h5py.File(fname1)

if 'stat_n_groups' not in d.keys():
  print("No stats found")
  sys.exit(1)


if (d['stat_n_groups'][0]!=n_groups):
  print("n_groups does not match:", d['stat_n_groups'][0],n_groups)
  sys.exit(1)
if (d['stat_n_permutations'][0]!=n_perms):
  print("n_perms does not match:",d['stat_n_permutations'][0],n_perms)
  sys.exit(1)

t1=d['stat_values'][0]
t2=value
m=abs((t1-t2)/t2)
if (m>precv):
    print("Value diff too large: %e>%e "%(m,precv))
    print("Raw data:",t1,t2)
    sys.exit(2)

t1=d['stat_pvalues'][0]
t2=pvalue
m=abs((t1-t2)/t2)
if (m>precp):
    print("P-Value diff too large: %e>%e "%(m,precp))
    print("Raw data:",t1,t2)
    sys.exit(2)

print("File matches within precision")



#!/usr/bin/env python

# Requires h5py library
# Usage:
#  compare_unifrac_stats_multi.py fname n_stats n_groups n_perms value pvalue prec_value prec_pvalue
#
# Example:
#  compare_unifrac_stats.py a.h5 10 5 99 1.001112 0.456  0.05 0.5
#
import h5py
import sys

fname1=sys.argv[1]
n_stats=int(sys.argv[2])
n_groups=int(sys.argv[3])
n_perms=int(sys.argv[4])
value=float(sys.argv[5])
pvalue=float(sys.argv[6])
precv=float(sys.argv[7])
precp=float(sys.argv[8])

d= h5py.File(fname1)

if 'stat_n_groups' not in d.keys():
  print("No stats found")
  sys.exit(1)

idxs=range(n_stats)

for i in idxs:
  if (d['stat_n_groups'][i]!=n_groups):
    print("n_groups does not match for %i:"%i, d['stat_n_groups'][i],n_groups)
    sys.exit(1)
  if (d['stat_n_permutations'][i]!=n_perms):
    print("n_perms does not match for %i:"%i,d['stat_n_permutations'][i],n_perms)
    sys.exit(1)

  t1=d['stat_values'][i]
  t2=value
  m=abs((t1-t2)/t2)
  if (m>precv):
    print("Value diff too large for %i: %e>%e "%(i,m,precv))
    print("Raw data:",t1,t2)
    sys.exit(2)

  t1=d['stat_pvalues'][i]
  t2=pvalue
  m=abs((t1-t2)/t2)
  if (m>precp):
    print("P-Value diff too large for %i: %e>%e "%(i,m,precp))
    print("Raw data:",t1,t2)
    sys.exit(2)

print("File matches within precision")
